#!/usr/bin/ksh
# =======================================================================
#
#                   Jet Propulsion Laboratory
#
#                  Atmospheric InfraRed Sounder
#
#      Copyright (c) 2000 - California Institute of Technology
#              U.S. Government Sponsorship under NASA
#                Contract NAS7-1270 is acknowledged
# !PROLOG ==================================================================
#
#
#------------------------------------------------------------------------------
#
# 1. DISCLAIMER
#    THE SOFTWARE AND/OR RELATED MATERIALS ARE PROVIDED "AS-IS" WITHOUT
#    WARRANTY OF ANY KIND INCLUDING ANY WARRANTIES OF PERFORMANCE OR
#    MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE OR PURPOSE (AS SET FORTH
#    IN UCC 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE LICENSED
#    PRODUCT, HOWEVER USED.
#
#    IN NO EVENT SHALL CALTECH/JPL BE LIABLE FOR ANY DAMAGES AND/OR COSTS,
#    INCLUDING BUT NOT LIMITED TO INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY
#    KIND, INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
#    REGARDLESS OF WHETHER CIT/JPL SHALL BE ADVISED, HAVE REASON TO KNOW,
#    OR IN FACT SHALL KNOW OF THE POSSIBILITY.
#
#    USER BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF THE SOFTWARE
#    AND/OR RELATED MATERIALS.
#
# 2. The user shall comply with all applicable U.S. export control laws and
#    regulations.  To the extent that the software is subject to U.S. export
#    control laws and regulations, the user has the responsibility to obtain
#    export licenses or other export authority as may be required before
#    exporting such information to foreign countries or providing access to
#    foreign persons.
#
#------------------------------------------------------------------------------
#
# !Routine/File Name:
#
#       L2.ksh
#
#
# !Description:
#
#    This is a script to run the Level-2 PGE
#
#    It returns 0 (success) unless Level_2 PGE fails.
#
#
# !Input Parameters:
#
#    Whether or not to apply compression is controlled by the PCF file
#    (specified by $PGS_PC_INFO_FILE) from Logical ID (LID) 1071
#
# !Output Parameters:
#
#    None
#
# !Input/Output Parameters:
#
#    None
#
#
# !Global Variables:
#
#    None
#
#
# !Known Bugs and Limitations:
#
#    None
#
#
# !Revision History:  
#
#    Available through CCC/Harvest.
#
#
# !END ==================================================================

run_level_2 
let RESULT=$?
if [ $RESULT -ne 0 ] ; then
   exit 1 
fi

# if LID 1071 "Processing Directives" includes the string "UnCompressed"
# then skip the compression
NOCOMPRESS=`PGS_PC_GetConfigDataCom 1071 | grep "UnCompressed"`
# echo "UnCompressed = " $NOCOMPRESS
if [[ $NOCOMPRESS == "" ]] then
   airs_l2ir_hrepack.pl
fi

exit 0

